#include "fftw.h"
#include <math.h>
#include <stdio.h>
#include <stdlib.h>

double sinc(double x) {
  if (x==0.0)
    return 1.0;
  else
    return sin(x)/x;
}

int main(int argc, char**argv) 
{
  // allocate arrays for function and its transform
  const unsigned long int n=16384;
  double complex *f    = malloc(sizeof(double complex)*n);
  double complex *fhat = malloc(sizeof(double complex)*n);
  if (f == NULL || fhat == NULL)
    return 1;

  // define the interval
  double x1 = -30; 
  double x2 =  30; 
  double dx =  (x2-x1)/(double)(n);
  
  // compute the function
  for (unsigned long int i=0;i<n;i++) {
    // map i to x such that i=0 and x=0 coincide
    double x = i*dx;
    // wrap around such that we cover the interval [x1:x2)
    if (x > x2)
      x -= (x2-x1);
    // compute and store function at x
    f[i] = sinc(x);
  }

  // perform fft using fftw3 in fftw.h
  fftw(n, f, fhat, 1); 
  
  // try to open a file
  FILE* file= fopen("output.dat", "w");
  if (file == NULL) 
    return 2;

  // write ft to it
  for (int i=0;i<n;i++) 
    fprintf(file,
            "%lf %lf %lf %lf\n", 
            creal(fhat[i]), cimag(fhat[i]), 
            creal(f[i]), cimag(f[i]));

  // clean up
  fclose(file);
  free(f);
  free(fhat);
}
